@@ -3,7 +3,7 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 # Store specs for use after JIT compilation (for inheritance)
 # This is accessed from XS via get_hv("Meow::SPECS", ...)
@@ -24,7 +24,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
@@ -41,6 +41,8 @@ This module is experimental. Many basic features do not yet exist.
 
 	rw age => Default(Num, 0);
 
+	make_immutable;
+
 	1;
 
 ...
@@ -51,6 +53,8 @@ This module is experimental. Many basic features do not yet exist.
 
 	extends qw/Cat/;
 
+	make_immutable;
+
 	1;
 
 ...
@@ -188,6 +192,8 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 
 		ro two => Default(Num, 200);
 
+		make_immutable;
+
 		1;
 	}
 
@@ -198,6 +204,8 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 		use Meow;
 		extends qw/Foo::Meow/;
 
+		make_immutable;
+
 		1;
 	}
 
@@ -249,36 +257,17 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 
 ...
 
-	Benchmark: timing 5,000,000 iterations of Marlin, Meow, Moo, Mouse...
-	    Marlin:  1 wallclock secs ( 0.98 usr +  0.02 sys =  1.00 CPU) @ 5000000.00/s (n=5000000)
-	      Meow:  1 wallclock secs ( 0.96 usr +  0.00 sys =  0.96 CPU) @ 5208333.33/s (n=5000000)
-	       Moo:  6 wallclock secs ( 5.70 usr +  0.00 sys =  5.70 CPU) @ 877192.98/s (n=5000000)
-	     Mouse:  3 wallclock secs ( 3.05 usr +  0.01 sys =  3.06 CPU) @ 1633986.93/s (n=5000000)
-
-		    Rate    Moo  Mouse Marlin   Meow
-	Moo     877193/s     --   -46%   -82%   -83%
-	Mouse  1633987/s    86%     --   -67%   -69%
-	Marlin 5000000/s   470%   206%     --    -4%
-	Meow   5208333/s   494%   219%     4%     --
-
-Note: Type::Tiny::XS is installed and so is the other optional XS dependancies for Moo.
-
-	Benchmark: running Cor, Marlin for at least 5 CPU seconds... Marlin and Meow has type constraint checking
-	       Cor:  5 wallclock secs ( 5.13 usr +  0.02 sys =  5.15 CPU) @ 2886788.16/s (n=14866959)
-	    Marlin:  5 wallclock secs ( 5.01 usr +  0.11 sys =  5.12 CPU) @ 4523074.80/s (n=23158143)
-	      Meow:  5 wallclock secs ( 5.16 usr + -0.01 sys =  5.15 CPU) @ 5196218.06/s (n=26760523)
-	
 	Benchmark: running Marlin, Meow, Moo, Mouse for at least 5 CPU seconds...
-	    Marlin:  5 wallclock secs ( 5.22 usr +  0.13 sys =  5.35 CPU) @ 4814728.04/s (n=25758795)
-	      Meow:  5 wallclock secs ( 5.23 usr +  0.01 sys =  5.24 CPU) @ 5203329.96/s (n=27265449)
-	       Moo:  4 wallclock secs ( 5.28 usr +  0.00 sys =  5.28 CPU) @ 860649.81/s (n=4544231)
-	     Mouse:  6 wallclock secs ( 5.29 usr +  0.01 sys =  5.30 CPU) @ 1603849.25/s (n=8500401)
+	    Marlin:  5 wallclock secs ( 5.27 usr +  0.13 sys =  5.40 CPU) @ 4770147.22/s (n=25758795)
+	      Meow:  5 wallclock secs ( 5.30 usr +  0.01 sys =  5.31 CPU) @ 6277761.96/s (n=33334916)
+	       Moo:  5 wallclock secs ( 5.28 usr + -0.00 sys =  5.28 CPU) @ 877202.65/s (n=4631630)
+	     Mouse:  5 wallclock secs ( 5.23 usr +  0.01 sys =  5.24 CPU) @ 1590405.73/s (n=8333726)
 
 		    Rate    Moo  Mouse Marlin   Meow
-	Moo     860650/s     --   -46%   -82%   -83%
-	Mouse  1603849/s    86%     --   -67%   -69%
-	Marlin 4814728/s   459%   200%     --    -7%
-	Meow   5203330/s   505%   224%     8%     --
+	Moo     877203/s     --   -45%   -82%   -86%
+	Mouse  1590406/s    81%     --   -67%   -75%
+	Marlin 4770147/s   444%   200%     --   -24%
+	Meow   6277762/s   616%   295%    32%     --
 
 =head1 AUTHOR
 
